aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorFlorent Villard <warly@mandriva.com>2006-10-16 16:35:11 +0000
committerFlorent Villard <warly@mandriva.com>2006-10-16 16:35:11 +0000
commitfd8fe296722bc8fb72604cd19a93a84f010ff1c3 (patch)
tree189f68f2e63938a28a67690004ace0c4547095d1 /lib
parent0a44a5718469afd7ba370a44510454a2ffe91aef (diff)
downloadmga-youri-core-fd8fe296722bc8fb72604cd19a93a84f010ff1c3.tar
mga-youri-core-fd8fe296722bc8fb72604cd19a93a84f010ff1c3.tar.gz
mga-youri-core-fd8fe296722bc8fb72604cd19a93a84f010ff1c3.tar.bz2
mga-youri-core-fd8fe296722bc8fb72604cd19a93a84f010ff1c3.tar.xz
mga-youri-core-fd8fe296722bc8fb72604cd19a93a84f010ff1c3.zip
merging dev with upstream
Diffstat (limited to 'lib')
-rw-r--r--lib/Youri/Media.pm30
1 files changed, 15 insertions, 15 deletions
diff --git a/lib/Youri/Media.pm b/lib/Youri/Media.pm
index 94bdf03..b2424be 100644
--- a/lib/Youri/Media.pm
+++ b/lib/Youri/Media.pm
@@ -49,9 +49,9 @@ Verbose mode (default: false).
list of ids of medias allowed to provide dependencies.
-=item skip_inputs $input_ids
+=item skip_tests $test_ids
-list of ids of input plugins to skip.
+list of ids of test plugins to skip.
=item skip_archs $arches
@@ -77,7 +77,7 @@ sub new {
verbose => 0, # verbose mode
allow_deps => undef, # list of media ids from which deps are allowed
allow_srcs => undef, # list of media ids from which packages can be built
- skip_inputs => undef, # list of inputs ids to skip
+ skip_tests => undef, # list of tests ids to skip
skip_archs => undef, # list of archs for which to skip tests
@_
);
@@ -88,7 +88,7 @@ sub new {
unless $options{type} =~ /^(?:binary|source)$/o;
# some options need to be arrays. Check it and convert to hashes
- foreach my $option (qw(allow_deps allow_srcs skip_archs skip_inputs)) {
+ foreach my $option (qw(allow_deps allow_srcs skip_archs skip_tests)) {
next unless defined $options{$option};
croak "$option should be an arrayref" unless ref $options{$option} eq 'ARRAY';
$options{$option} = {
@@ -103,7 +103,7 @@ sub new {
_allow_deps => $options{allow_deps},
_allow_srcs => $options{allow_srcs},
_skip_archs => $options{skip_archs},
- _skip_inputs => $options{skip_inputs},
+ _skip_tests => $options{skip_tests},
}, $class;
$self->_init(%options);
@@ -248,32 +248,32 @@ sub skip_arch {
$self->{_skip_archs}->{$arch};
}
-=head2 skip_inputs()
+=head2 skip_tests()
-Returns the list of id of input which are to be skipped for this media.
+Returns the list of id of test which are to be skipped for this media.
=cut
-sub skip_inputs {
+sub skip_tests {
my ($self) = @_;
croak "Not a class method" unless ref $self;
- return keys %{$self->{_skip_inputs}};
+ return keys %{$self->{_skip_tests}};
}
-=head2 skip_input($input_id)
+=head2 skip_test($test_id)
-Tells wether input with given id is to be skipped for this media.
+Tells wether test with given id is to be skipped for this media.
=cut
-sub skip_input {
- my ($self, $input) = @_;
+sub skip_test {
+ my ($self, $test) = @_;
croak "Not a class method" unless ref $self;
return
- $self->{_skip_inputs}->{all} ||
- $self->{_skip_inputs}->{$input};
+ $self->{_skip_tests}->{all} ||
+ $self->{_skip_tests}->{$test};
}
=head2 get_package_class()